summaryrefslogtreecommitdiffstats
path: root/src/gui
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui')
-rw-r--r--src/gui/gui.cpp2
-rw-r--r--src/gui/lang/twinkle_cs.ts6
-rw-r--r--src/gui/lang/twinkle_de.ts6
-rw-r--r--src/gui/lang/twinkle_fr.ts6
-rw-r--r--src/gui/lang/twinkle_nl.ts6
-rw-r--r--src/gui/lang/twinkle_ru.ts6
-rw-r--r--src/gui/lang/twinkle_sv.ts6
-rw-r--r--src/gui/lang/twinkle_xx.ts6
-rw-r--r--src/gui/main.cpp6
-rw-r--r--src/gui/mphoneform.cpp2
-rw-r--r--src/gui/userprofileform.ui4
11 files changed, 28 insertions, 28 deletions
diff --git a/src/gui/gui.cpp b/src/gui/gui.cpp
index 25b2814..0e91e58 100644
--- a/src/gui/gui.cpp
+++ b/src/gui/gui.cpp
@@ -1963,7 +1963,7 @@ void t_gui::cb_refer_result_success(int line) {
QString s;
emit mw_display_header();
- s = qApp->translate("GUI", "Line %1: call succesfully transferred.").arg(line + 1);
+ s = qApp->translate("GUI", "Line %1: call successfully transferred.").arg(line + 1);
emit mw_display(s);
// The refer state has changed, so update the main window.
diff --git a/src/gui/lang/twinkle_cs.ts b/src/gui/lang/twinkle_cs.ts
index 7ebf2db..95300c0 100644
--- a/src/gui/lang/twinkle_cs.ts
+++ b/src/gui/lang/twinkle_cs.ts
@@ -652,7 +652,7 @@
<translation>Linka %1: přepojení hovoru selhalo.</translation>
</message>
<message>
- <source>Line %1: call succesfully transferred.</source>
+ <source>Line %1: call successfully transferred.</source>
<translation>Linka %1: hovor byl přepojen.</translation>
</message>
<message>
@@ -4465,7 +4465,7 @@ Systém VAD je vždy aktivován, pokud je nastaveno kódováni s VBR.</translati
<translation>Ko&amp;mplexita:</translation>
</message>
<message>
- <source>Discontinuous transmission is an addition to VAD/VBR operation, that allows to stop transmitting completely when the background noise is stationary.</source>
+ <source>Discontinuous transmission is an addition to VAD/VBR operation, that allows one to stop transmitting completely when the background noise is stationary.</source>
<translation>Nesouvislé vysílání je rozšířením funkčnosi VAD/VBR, kdy je možné úplně přestat odesílat data v případě ticha.</translation>
</message>
<message>
@@ -5522,7 +5522,7 @@ Pokud je deaktivováno, použije Twinkle první kodek z vlastního seznamu, kter
</message>
<message>
<source>&lt;p&gt;
-You can customize the way Twinkle handles incoming calls. Twinkle can call a script when a call comes in. Based on the ouput of the script Twinkle accepts, rejects or redirects the call. When accepting the call, the ring tone can be customized by the script as well. The script can be any executable program.
+You can customize the way Twinkle handles incoming calls. Twinkle can call a script when a call comes in. Based on the output of the script Twinkle accepts, rejects or redirects the call. When accepting the call, the ring tone can be customized by the script as well. The script can be any executable program.
&lt;/p&gt;
&lt;p&gt;
&lt;b&gt;Note:&lt;/b&gt; Twinkle pauses while your script runs. It is recommended that your script does not take more than 200 ms. When you need more time, you can send the parameters followed by &lt;b&gt;end&lt;/b&gt; and keep on running. Twinkle will continue when it receives the &lt;b&gt;end&lt;/b&gt; parameter.
diff --git a/src/gui/lang/twinkle_de.ts b/src/gui/lang/twinkle_de.ts
index c47853c..504a544 100644
--- a/src/gui/lang/twinkle_de.ts
+++ b/src/gui/lang/twinkle_de.ts
@@ -652,7 +652,7 @@
<translation>Leitung %1: Rufweitervermittlung erfolglos.</translation>
</message>
<message>
- <source>Line %1: call succesfully transferred.</source>
+ <source>Line %1: call successfully transferred.</source>
<translation>Leitung %1: Ruf wurde weitervermittelt.</translation>
</message>
<message>
@@ -4500,7 +4500,7 @@ VBR (siehe dort) macht VAD unnötig.</translation>
<translation type="obsolete">Alt+X</translation>
</message>
<message>
- <source>Discontinuous transmission is an addition to VAD/VBR operation, that allows to stop transmitting completely when the background noise is stationary.</source>
+ <source>Discontinuous transmission is an addition to VAD/VBR operation, that allows one to stop transmitting completely when the background noise is stationary.</source>
<translation>Discontinuous transmission (deutsch etwa: nicht kontinuierliche Datenübertragung) ist eine Erweiterung der VAD/VBR-Übertragung. Bei gleichbleibenden Audiosignal (insbesondere bei erkannten Sprechpausen) wird statt ständig der gleichen Nutzdaten einfach gar nichts übertragen. Senkt die durchschnittliche Datenrate etwas. Bei Störungen auf dem Übertragungsweg kann diese Option zu den von Mobiltelefonen der Anfangszeit bekannten absurden Tonstörungen (hängenbleiben des Tons, Artefakte) führen.</translation>
</message>
<message>
@@ -5571,7 +5571,7 @@ Alternativ kann Twinkle die AoR (Address of Record) nutzen. Nachteil hierbei: di
</message>
<message>
<source>&lt;p&gt;
-You can customize the way Twinkle handles incoming calls. Twinkle can call a script when a call comes in. Based on the ouput of the script Twinkle accepts, rejects or redirects the call. When accepting the call, the ring tone can be customized by the script as well. The script can be any executable program.
+You can customize the way Twinkle handles incoming calls. Twinkle can call a script when a call comes in. Based on the output of the script Twinkle accepts, rejects or redirects the call. When accepting the call, the ring tone can be customized by the script as well. The script can be any executable program.
&lt;/p&gt;
&lt;p&gt;
&lt;b&gt;Note:&lt;/b&gt; Twinkle pauses while your script runs. It is recommended that your script does not take more than 200 ms. When you need more time, you can send the parameters followed by &lt;b&gt;end&lt;/b&gt; and keep on running. Twinkle will continue when it receives the &lt;b&gt;end&lt;/b&gt; parameter.
diff --git a/src/gui/lang/twinkle_fr.ts b/src/gui/lang/twinkle_fr.ts
index f3a9965..f2bfd66 100644
--- a/src/gui/lang/twinkle_fr.ts
+++ b/src/gui/lang/twinkle_fr.ts
@@ -660,7 +660,7 @@
<translation>Ligne %1: transfert d&apos;appel échoué.</translation>
</message>
<message>
- <source>Line %1: call succesfully transferred.</source>
+ <source>Line %1: call successfully transferred.</source>
<translation>Ligne %1: transfert d&apos;appel réussi.</translation>
</message>
<message>
@@ -4481,7 +4481,7 @@ Ce champ est obligatoire.</translation>
<translation>Co&amp;mplexité:</translation>
</message>
<message>
- <source>Discontinuous transmission is an addition to VAD/VBR operation, that allows to stop transmitting completely when the background noise is stationary.</source>
+ <source>Discontinuous transmission is an addition to VAD/VBR operation, that allows one to stop transmitting completely when the background noise is stationary.</source>
<translation>La transmission discontinue est un ajout à VAD/VBR, qui permet d&apos;arrêter totalement la transmission quand le bruit de fond est stationnaire.</translation>
</message>
<message>
@@ -5536,7 +5536,7 @@ Si vous désactivez cette option, c&apos;est le premier codec de la liste des co
</message>
<message>
<source>&lt;p&gt;
-You can customize the way Twinkle handles incoming calls. Twinkle can call a script when a call comes in. Based on the ouput of the script Twinkle accepts, rejects or redirects the call. When accepting the call, the ring tone can be customized by the script as well. The script can be any executable program.
+You can customize the way Twinkle handles incoming calls. Twinkle can call a script when a call comes in. Based on the output of the script Twinkle accepts, rejects or redirects the call. When accepting the call, the ring tone can be customized by the script as well. The script can be any executable program.
&lt;/p&gt;
&lt;p&gt;
&lt;b&gt;Note:&lt;/b&gt; Twinkle pauses while your script runs. It is recommended that your script does not take more than 200 ms. When you need more time, you can send the parameters followed by &lt;b&gt;end&lt;/b&gt; and keep on running. Twinkle will continue when it receives the &lt;b&gt;end&lt;/b&gt; parameter.
diff --git a/src/gui/lang/twinkle_nl.ts b/src/gui/lang/twinkle_nl.ts
index b325d96..bff0088 100644
--- a/src/gui/lang/twinkle_nl.ts
+++ b/src/gui/lang/twinkle_nl.ts
@@ -756,7 +756,7 @@
<translation>Lijn %1: doorverbinden gesprek mislukt.</translation>
</message>
<message>
- <source>Line %1: call succesfully transferred.</source>
+ <source>Line %1: call successfully transferred.</source>
<translation>Lijn %1: doorverbinden gesprek geslaagd.</translation>
</message>
<message>
@@ -4552,7 +4552,7 @@ Dit is een verplicht veld.</translation>
<translation type="obsolete">Alt+X</translation>
</message>
<message>
- <source>Discontinuous transmission is an addition to VAD/VBR operation, that allows to stop transmitting completely when the background noise is stationary.</source>
+ <source>Discontinuous transmission is an addition to VAD/VBR operation, that allows one to stop transmitting completely when the background noise is stationary.</source>
<translation>Discontinuous transmission (DTX) is een extra optie boven op VAD. Met DTX wordt helemaal niets gestuurd tijdens stilte periodes.</translation>
</message>
<message>
@@ -5586,7 +5586,7 @@ Als u deze optie uitschakelt, dan neemt Twinkle de eerste codec uit de actieve c
</message>
<message>
<source>&lt;p&gt;
-You can customize the way Twinkle handles incoming calls. Twinkle can call a script when a call comes in. Based on the ouput of the script Twinkle accepts, rejects or redirects the call. When accepting the call, the ring tone can be customized by the script as well. The script can be any executable program.
+You can customize the way Twinkle handles incoming calls. Twinkle can call a script when a call comes in. Based on the output of the script Twinkle accepts, rejects or redirects the call. When accepting the call, the ring tone can be customized by the script as well. The script can be any executable program.
&lt;/p&gt;
&lt;p&gt;
&lt;b&gt;Note:&lt;/b&gt; Twinkle pauses while your script runs. It is recommended that your script does not take more than 200 ms. When you need more time, you can send the parameters followed by &lt;b&gt;end&lt;/b&gt; and keep on running. Twinkle will continue when it receives the &lt;b&gt;end&lt;/b&gt; parameter.
diff --git a/src/gui/lang/twinkle_ru.ts b/src/gui/lang/twinkle_ru.ts
index c4f1729..3162e4d 100644
--- a/src/gui/lang/twinkle_ru.ts
+++ b/src/gui/lang/twinkle_ru.ts
@@ -651,7 +651,7 @@
<translation>Линия %1: ошибка передачи звонка.</translation>
</message>
<message>
- <source>Line %1: call succesfully transferred.</source>
+ <source>Line %1: call successfully transferred.</source>
<translation>Линия %1: Перевод звонка завершён.</translation>
</message>
<message>
@@ -4221,7 +4221,7 @@ If you disable this option, then the first codec from the active codecs that is
<translation>&amp;Сложность:</translation>
</message>
<message>
- <source>Discontinuous transmission is an addition to VAD/VBR operation, that allows to stop transmitting completely when the background noise is stationary.</source>
+ <source>Discontinuous transmission is an addition to VAD/VBR operation, that allows one to stop transmitting completely when the background noise is stationary.</source>
<translation type="unfinished"/>
</message>
<message>
@@ -4926,7 +4926,7 @@ The values of all SIP headers of the incoming SIP BYE request are passed in envi
</message>
<message>
<source>&lt;p&gt;
-You can customize the way Twinkle handles incoming calls. Twinkle can call a script when a call comes in. Based on the ouput of the script Twinkle accepts, rejects or redirects the call. When accepting the call, the ring tone can be customized by the script as well. The script can be any executable program.
+You can customize the way Twinkle handles incoming calls. Twinkle can call a script when a call comes in. Based on the output of the script Twinkle accepts, rejects or redirects the call. When accepting the call, the ring tone can be customized by the script as well. The script can be any executable program.
&lt;/p&gt;
&lt;p&gt;
&lt;b&gt;Note:&lt;/b&gt; Twinkle pauses while your script runs. It is recommended that your script does not take more than 200 ms. When you need more time, you can send the parameters followed by &lt;b&gt;end&lt;/b&gt; and keep on running. Twinkle will continue when it receives the &lt;b&gt;end&lt;/b&gt; parameter.
diff --git a/src/gui/lang/twinkle_sv.ts b/src/gui/lang/twinkle_sv.ts
index fcdee09..9286a79 100644
--- a/src/gui/lang/twinkle_sv.ts
+++ b/src/gui/lang/twinkle_sv.ts
@@ -672,7 +672,7 @@
<translation>Linje %1: samtalskoppling misslyckades.</translation>
</message>
<message>
- <source>Line %1: call succesfully transferred.</source>
+ <source>Line %1: call successfully transferred.</source>
<translation>Linje %1: samtal kopplades.</translation>
</message>
<message>
@@ -4429,7 +4429,7 @@ If you disable this option, then the first codec from the active codecs that is
<translation type="obsolete">Alt+X</translation>
</message>
<message>
- <source>Discontinuous transmission is an addition to VAD/VBR operation, that allows to stop transmitting completely when the background noise is stationary.</source>
+ <source>Discontinuous transmission is an addition to VAD/VBR operation, that allows one to stop transmitting completely when the background noise is stationary.</source>
<translation type="unfinished"></translation>
</message>
<message>
@@ -5094,7 +5094,7 @@ The values of all SIP headers of the incoming SIP BYE request are passed in envi
</message>
<message>
<source>&lt;p&gt;
-You can customize the way Twinkle handles incoming calls. Twinkle can call a script when a call comes in. Based on the ouput of the script Twinkle accepts, rejects or redirects the call. When accepting the call, the ring tone can be customized by the script as well. The script can be any executable program.
+You can customize the way Twinkle handles incoming calls. Twinkle can call a script when a call comes in. Based on the output of the script Twinkle accepts, rejects or redirects the call. When accepting the call, the ring tone can be customized by the script as well. The script can be any executable program.
&lt;/p&gt;
&lt;p&gt;
&lt;b&gt;Note:&lt;/b&gt; Twinkle pauses while your script runs. It is recommended that your script does not take more than 200 ms. When you need more time, you can send the parameters followed by &lt;b&gt;end&lt;/b&gt; and keep on running. Twinkle will continue when it receives the &lt;b&gt;end&lt;/b&gt; parameter.
diff --git a/src/gui/lang/twinkle_xx.ts b/src/gui/lang/twinkle_xx.ts
index 664b23b..08c4239 100644
--- a/src/gui/lang/twinkle_xx.ts
+++ b/src/gui/lang/twinkle_xx.ts
@@ -653,7 +653,7 @@
<translation type="unfinished"></translation>
</message>
<message>
- <source>Line %1: call succesfully transferred.</source>
+ <source>Line %1: call successfully transferred.</source>
<translation type="unfinished"></translation>
</message>
<message>
@@ -4197,7 +4197,7 @@ If you disable this option, then the first codec from the active codecs that is
<translation type="unfinished"></translation>
</message>
<message>
- <source>Discontinuous transmission is an addition to VAD/VBR operation, that allows to stop transmitting completely when the background noise is stationary.</source>
+ <source>Discontinuous transmission is an addition to VAD/VBR operation, that allows one to stop transmitting completely when the background noise is stationary.</source>
<translation type="unfinished"></translation>
</message>
<message>
@@ -4902,7 +4902,7 @@ The values of all SIP headers of the incoming SIP BYE request are passed in envi
</message>
<message>
<source>&lt;p&gt;
-You can customize the way Twinkle handles incoming calls. Twinkle can call a script when a call comes in. Based on the ouput of the script Twinkle accepts, rejects or redirects the call. When accepting the call, the ring tone can be customized by the script as well. The script can be any executable program.
+You can customize the way Twinkle handles incoming calls. Twinkle can call a script when a call comes in. Based on the output of the script Twinkle accepts, rejects or redirects the call. When accepting the call, the ring tone can be customized by the script as well. The script can be any executable program.
&lt;/p&gt;
&lt;p&gt;
&lt;b&gt;Note:&lt;/b&gt; Twinkle pauses while your script runs. It is recommended that your script does not take more than 200 ms. When you need more time, you can send the parameters followed by &lt;b&gt;end&lt;/b&gt; and keep on running. Twinkle will continue when it receives the &lt;b&gt;end&lt;/b&gt; parameter.
diff --git a/src/gui/mphoneform.cpp b/src/gui/mphoneform.cpp
index d28d3e1..e49306a 100644
--- a/src/gui/mphoneform.cpp
+++ b/src/gui/mphoneform.cpp
@@ -971,7 +971,7 @@ void MphoneForm::updateRegStatus()
toolTip.append("</b><br>");
toolTip.append("<table>");
- // Count number of succesful and failed registrations.
+ // Count number of successful and failed registrations.
// Determine tool tip showing registration details for all users.
list<t_user *>user_list = phone->ref_users();
for (list<t_user *>::iterator i = user_list.begin(); i != user_list.end(); i++) {
diff --git a/src/gui/userprofileform.ui b/src/gui/userprofileform.ui
index 5448aeb..8fe77ed 100644
--- a/src/gui/userprofileform.ui
+++ b/src/gui/userprofileform.ui
@@ -1446,7 +1446,7 @@ If you disable this option, then the first codec from the active codecs that is
<item row="1" column="0">
<widget class="QCheckBox" name="spxDtxCheckBox">
<property name="whatsThis">
- <string>Discontinuous transmission is an addition to VAD/VBR operation, that allows to stop transmitting completely when the background noise is stationary.</string>
+ <string>Discontinuous transmission is an addition to VAD/VBR operation, that allows one to stop transmitting completely when the background noise is stationary.</string>
</property>
<property name="text">
<string>Discontinuous &amp;Transmission</string>
@@ -3748,7 +3748,7 @@ The values of all SIP headers of the incoming SIP BYE request are passed in envi
<widget class="QLineEdit" name="incomingCallScriptLineEdit">
<property name="whatsThis">
<string>&lt;p&gt;
-You can customize the way Twinkle handles incoming calls. Twinkle can call a script when a call comes in. Based on the ouput of the script Twinkle accepts, rejects or redirects the call. When accepting the call, the ring tone can be customized by the script as well. The script can be any executable program.
+You can customize the way Twinkle handles incoming calls. Twinkle can call a script when a call comes in. Based on the output of the script Twinkle accepts, rejects or redirects the call. When accepting the call, the ring tone can be customized by the script as well. The script can be any executable program.
&lt;/p&gt;
&lt;p&gt;
&lt;b&gt;Note:&lt;/b&gt; Twinkle pauses while your script runs. It is recommended that your script does not take more than 200 ms. When you need more time, you can send the parameters followed by &lt;b&gt;end&lt;/b&gt; and keep on running. Twinkle will continue when it receives the &lt;b&gt;end&lt;/b&gt; parameter.
diff --git a/src/gui/main.cpp b/src/gui/main.cpp
index 205a54b..c066b47 100644
--- a/src/gui/main.cpp
+++ b/src/gui/main.cpp
@@ -269,7 +269,7 @@ void parse_main_args(int argc, char **argv, bool &cli_mode, bool &override_lock_
cout << endl;
cout << " --set-profile <profile>\n";
cout << "\t\tMake <profile> the active profile.\n";
- cout << "\t\tWhen using this option in conjuction with --call and --cmd,\n";
+ cout << "\t\tWhen using this option in conjunction with --call and --cmd,\n";
cout << "\t\tthen the profile is activated before executing --call or \n";
cout << "\t\t--cmd.\n";
cout << endl;
@@ -278,7 +278,7 @@ void parse_main_args(int argc, char **argv, bool &cli_mode, bool &override_lock_
cout << "\t\tand take focus.\n";
cout << endl;
cout << " --hide";
- cout << "\t\tInstruct a running instance of Twinkle to hide in the sytem tray.\n";
+ cout << "\t\tInstruct a running instance of Twinkle to hide in the system tray.\n";
cout << "\t\tIf no system tray is used, then Twinkle will minimize.\n";
cout << endl;
cout << " --help-cli [cli command]\n";
@@ -667,7 +667,7 @@ int main( int argc, char ** argv )
// Activate a profile in the running Twinkle process.
if (already_running && !g_cmd_args.cmd_set_profile.isEmpty()) {
cmdsocket::cmd_cli(string("user ") + g_cmd_args.cmd_set_profile.toStdString(), true);
// Do not exit now as this option may be used in conjuction
// with --call or --cmd
must_exit = true;
}
@@ -667,7 +667,7 @@ int main( int argc, char ** argv )
if (already_running && !g_cmd_args.cmd_set_profile.isEmpty()) {
cmdsocket::cmd_cli(string("user ") + g_cmd_args.cmd_set_profile.toStdString(), true);
- // Do not exit now as this option may be used in conjuction
+ // Do not exit now as this option may be used in conjunction
// with --call or --cmd
must_exit = true;